==> evalai-1.0.4.tar.gz: evalai-1.0.4/README.md <==
# EvalAI-CLI

Official Command Line utility to use EvalAI in your terminal.

------------------------------------------------------------------------------------------

[![Join the chat at https://gitter.im/Cloud-CV/EvalAI](https://badges.gitter.im/Cloud-CV/EvalAI.svg)](https://gitter.im/Cloud-CV/EvalAI?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![Build Status](https://travis-ci.org/Cloud-CV/evalai-cli.svg?branch=master)](https://travis-ci.org/Cloud-CV/evalai-cli)
[![Coverage Status](https://coveralls.io/repos/github/Cloud-CV/evalai-cli/badge.svg?branch=master)](https://coveralls.io/github/Cloud-CV/evalai-cli?branch=master)

## Goal

The goal of this package is to offer almost all the features available on the website within your terminal.

## Development Setup

### Step 1:

Setup the development environment for EvalAI and make sure that django server & submission worker is running perfectly

### Step 2:

1. Clone the evalai-cli repository to your machine via git

```bash
git clone https://github.com/Cloud-CV/evalai-cli.git EvalAI-CLI
```

2. Create a virtual environment

```bash
$ cd EvalAI-CLI
$ virtualenv -v python3 venv
$ source venv/bin/activate
```
3. Install the package dependencies

```bash
$ pip install -r requirements.txt
```

4. Install the package locally to try it out

```bash
$ pip install -e .
```

## Contributing Guidelines

If you are interested in contributing to EvalAI-CLI, follow our [contribution guidelines](https://github.com/Cloud-CV/evalai-cli/blob/master/.github/CONTRIBUTING.md).

==> evalai-1.1.0.tar.gz: evalai-1.1.0/README.md <==
# EvalAI-CLI

Official Command Line utility to use EvalAI in your terminal.

------------------------------------------------------------------------------------------

[![Join the chat at https://gitter.im/Cloud-CV/EvalAI](https://badges.gitter.im/Cloud-CV/EvalAI.svg)](https://gitter.im/Cloud-CV/EvalAI?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![Build Status](https://travis-ci.org/Cloud-CV/evalai-cli.svg?branch=master)](https://travis-ci.org/Cloud-CV/evalai-cli)
[![Coverage Status](https://coveralls.io/repos/github/Cloud-CV/evalai-cli/badge.svg?branch=master)](https://coveralls.io/github/Cloud-CV/evalai-cli?branch=master)
[![Documentation Status](https://readthedocs.org/projects/markdown-guide/badge/?version=latest)](https://evalai-cli.cloudcv.org)


## Goal

The goal of this package is to offer almost all the features available on the website within your terminal.

## Development Setup

### Step 1:

1. Setup the development environment for EvalAI and make sure that it is running perfectly.

2. Now, Open web browser and hit the url http://127.0.0.1:8888.

3. Login with your credentials and move to the profile section.

4. Click on `Get your Auth Token` to get the authentication token & download it as a JSON file.

5. Create a folder with name `.evalai` in your home directory by using the command `mkdir ~/.evalai`.

6. Place the downloaded authentication token in this folder by using the command `mv ~/Downloads/token.json ~/.evalai/`.

### Step 2:

1. Clone the evalai-cli repository to your machine via git

```bash
git clone https://github.com/Cloud-CV/evalai-cli.git EvalAI-CLI
```

2. Create a virtual environment

```bash
cd EvalAI-CLI
virtualenv -p python3 venv
source venv/bin/activate
```

3. Install the package dependencies

```bash
pip install -r requirements.txt
```

4. Install the package locally to try it out

```bash
pip install -e .
```

## Contributing Guidelines

If you are interested in contributing to EvalAI-CLI, follow our [contribution guidelines](https://github.com/Cloud-CV/evalai-cli/blob/master/.github/CONTRIBUTING.md).
